==> haskell-hjsonschema-1.7.2-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.7.2
id: hjsonschema-1.7.2-LguArbd6TAL16PkmUig9Wk
key: hjsonschema-1.7.2-LguArbd6TAL16PkmUig9Wk
license: MIT
maintainer: ian@housejeffries.com
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
author: Ian Grant Jeffries
exposed: True
indefinite: False
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
abi: 5d4c5b88ed57f81f9f2149736bd994bb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hjsonschema-1.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hjsonschema-1.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hjsonschema-1.7.2
hs-libraries: HShjsonschema-1.7.2-LguArbd6TAL16PkmUig9Wk
depends:
    base-4.10.1.0 aeson-1.2.4.0-J0IgGfvF9B28Ryy7NsOCPv
    bytestring-0.10.8.2 containers-0.5.10.2
    file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG filepath-1.4.1.2
    hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    hjsonpointer-1.3.0-BK3G6zlI1SKJcjw3W3nbJE
    http-client-0.5.10-HLDKIWCSE4P5fAhIOZCIPF
    http-types-0.9.1-BD2l1Kzs7Ve6mp82UloTud
    pcre-heavy-1.0.0.2-2zQkJwPVRym8FYkH4MDXt3
    profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A
    protolude-0.2.1-AFXzOTXfFyQ1NF1eauEh0l
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
    scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             aeson-1.2.4.0-J0IgGfvF9B28Ryy7NsOCPv=cb689fc7acd6290bc554164c78e4d251
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=290747ebe676cf9f89313503a2e38e54
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             hjsonpointer-1.3.0-BK3G6zlI1SKJcjw3W3nbJE=cce96a76a06abf5be729b52af18c0e9a
             http-client-0.5.10-HLDKIWCSE4P5fAhIOZCIPF=7070c341ccebf232fdd13bca3f27776c
             http-types-0.9.1-BD2l1Kzs7Ve6mp82UloTud=1efefe4d9e28b8d4aa72d634a67d063f
             pcre-heavy-1.0.0.2-2zQkJwPVRym8FYkH4MDXt3=ce69157515f2354c8dbfb457521df2c9
             profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A=908044a83daa6649d4a3896409f07b7b
             protolude-0.2.1-AFXzOTXfFyQ1NF1eauEh0l=680234d64f707cf1bdd27a380a5d98a9
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             scientific-0.3.5.2-8Zc2VroUo3iF9E3c5Pz1Qw=11abcce15758b0e3fff5fe5ecd138e8b
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonschema-1.7.2-42-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.7.2
id: hjsonschema-1.7.2-rFu8KLsrFJAHyx5MO26H
key: hjsonschema-1.7.2-rFu8KLsrFJAHyx5MO26H
license: MIT
maintainer: ian@housejeffries.com
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
author: Ian Grant Jeffries
exposed: True
indefinite: False
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
abi: be7a2415ec57e37a623b8962cd7cf82a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hjsonschema-1.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hjsonschema-1.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hjsonschema-1.7.2
hs-libraries: HShjsonschema-1.7.2-rFu8KLsrFJAHyx5MO26H
depends:
    base-4.10.1.0 aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD
    bytestring-0.10.8.2 containers-0.5.10.2
    file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG filepath-1.4.1.2
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    hjsonpointer-1.3.0-LkbXuQupdRYHvjzFjkaRJ9
    http-client-0.5.10-LdpiSnFx6rbIfMp9cUc91I
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX
    pcre-heavy-1.0.0.2-2L1OHdODOL55vHzaKs2fYQ
    profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A
    protolude-0.2.1-4RdtrWa7zl3GV08SHsKJfu
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             aeson-1.2.4.0-29Ui7SKICkn4HdMa5tx6LD=2daf6700d9ef385ba2659a6e8aebe988
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             file-embed-0.0.10.1-dHJWrXRvu59h2yyMVhlwG=290747ebe676cf9f89313503a2e38e54
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             hjsonpointer-1.3.0-LkbXuQupdRYHvjzFjkaRJ9=fbc46c19686c3b05c1f60583e3a6cafd
             http-client-0.5.10-LdpiSnFx6rbIfMp9cUc91I=27bfb0dcab6acb151c1732b313017308
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             pcre-heavy-1.0.0.2-2L1OHdODOL55vHzaKs2fYQ=94bb66d67f2f41511eed37f2b2752b4a
             profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A=908044a83daa6649d4a3896409f07b7b
             protolude-0.2.1-4RdtrWa7zl3GV08SHsKJfu=58cf2501ba7dd8ff6ef7353a674c5275
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
